@@ -1,6 +1,7 @@
 import os
 import pandas as pd
 from spongebox.reg import filter_list
+from spongebox.time import timeit
 
 pd.set_option('display.max_rows', 500)
 pd.set_option('display.max_columns', 500)
@@ -16,11 +17,14 @@ def list_dir(dir_path, exp=None):
     else:
         return filter_list(os.listdir(dir_path), exp=exp)
 
-
+@timeit
 def list_all_files(dir_path):
     lst=[]
-    for root,dir,f in os.walk(dir_path):
-        lst.extend(f)
+    for root,dir,flst in os.walk(dir_path):
+        # print(root)
+        # print(dir)
+        # print(flst)
+        lst.extend([root+"\\"+f for f in flst])
     return lst
 
 
@@ -31,5 +35,5 @@ if __name__ == "__main__":
     # print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test",lst))
     # print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test",lst1))
     # print(walk_all_files("C:\\Users\\LuoJi\\Downloads\\test"))
-    # list_all_files("C:\\Users\\LuoJi\\Documents\\05照片", lst)
-    print(walk_all_files("."))
\ No newline at end of file
+    list_all_files("C:\\Users\\LuoJi\\Documents\\05照片")
+    # print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test"))
\ No newline at end of file
